bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 32. Aventiure
___________________________________________________
| ### Bloedelines> recken di waren alle gar ### mit tvsent halspergen hvben si sich dar ### da Danchwart mit den knehten ob dem thisse saz ### da hvb sich vnder helden der aller grozeste haz ### Also der herre Bloedelin fver di thisse gie ### Danchwart der marschalch in vlizechliche enpfie ### willechomen her ce hvse <min> her Bloedelin ### ia wndert mich der mære waz sol disiv rede sin
###### 1920 | ### Iane dverfet ir mich niht grvezen so sprach Blodelin ### wan diz chomen daz mine daz mvz din ende sin ### dvrch Hagenen dinen brvder der Sifriden slvch ### des engiltest du hi cen Hivnen [387b] vnd <ander> degene genvch
| ### Neina herre Bloedelin so sprach do Danchwart ### so moeht vns wol balde riwen disiv hovevart ### ich was <ein> wenich kindelin do Sifrit vlos den lip ### ine weiz niht waz mir wizzet des kvenech Eceln wip
###### 1922 | ### Iane weiz ich dir der mære niht ce sagene ### ez taten dine mage Gventher vnde Hagene ### nv wert ivch vil ellenden ir chvennet niht genesen ### ir mvezet mit dem tode pfant daz Criemhilde wesen
###### 1923 | ### Sone welt ir niht erwinden so sprach Danchwart ### so riwet mich min vlehen daz wære baz gespart ### der snelle degen chvene von dem thisse spranch ### er zoch ein scharpfez waffen daz was michel vnde lanch
| ### Do slvch er Blodeline einen swinden swertes slach ### daz im daz hovbet schiere vor den fvezen gelach ### daz si din morgengabe sprach Danchwart der degen ### zv Nvdvnges brvete der dv mit minnen woldest pflegen
###### 1925 | ### Man mach si morgen mehelen einem anderm man ### wil er di brvtmiete dem wirt alsam getan ### ein vil getriwer Hivne het im daz geseit ### daz im div chveneginne riet so groziv leit
###### 1926 | ### Do sahen Bloedelines man ir herre lach erslagen ### done wolden si den gesten niht langer daz vertragen ### mit vf erbvrten swerten si sprvngen fver div chint ### in grimmigem mvote daz gerav vil manigen sint
| ### Vil lvte rief do Danchwart daz gesinde allez an ### ir seht wol edeln chnehte wi ez wil vmbe gan ### nv wert ivch vil ellenden deiswar des gat vns not ### swi vns div edele Crimhilt so rehte gvetlich enbot
###### 1928 | ### Di niht swert enheten di reichten fver di banch ### vnde hvben von den fvezen vil manegen shamel lanch ### der Bvrgonden knehte in wolden niht vertragen ### da wart von swæren stvelen dvrch helme bveln vil geslagen
###### 1929 | ### Wi grimme sich do werten div ellendn [388a] chint ### si triben vz dem hvse di gevaffenten sint ### doch beleip ir tot dar inne fvnf hvndert oder baz ### do was daz ingesinde von blvte rot vnde naz
| ### Disiv starchen mære wrden dan geseit ### den Eceln recken ez was in grimme leit ### daz erslagen wære Blodel vnd sine man ### daz het Hagen brvder mit den knehten getan
###### 1931 | ### E ez div chvneginne erfvende di Hivnen dvrch ir haz ### der garte sich zwei tvsent oder dannoch baz ### si giengen zv den knehten daz mvs et also wesen ### vnde liezen des gesindes ninder einen genesen
###### 1932 | ### Di vngetriwen brahten fver das hvs ein michel her ### di ellenden knehte di stvndne wol ce wer ### waz half ir baldez ellen si mvsen ligen tot ### dar nach in chvrcen stvnden hvb sich ein vreislichiv not
| ### Hi mveget ir hoeren wnder bi vngefvoge sagen ### nivn tvsent knehte di lagen tot erslagen ### dar veber ritter zwelfe der Danchwartes man ### man sah in alterseine noch bi den vianden stan
###### 1934 | ### Der schal der was geswiftet der doz der was gelegen ### do blichte veber ahsel Danchwart der degen ### er sprah owe der frivnde di ich verlorn han ### nv mvz ich leider eine bi minen fianden stan
###### 1935 | ### Div swert genote vielen vf sin eines lip ### daz mvse sit beweinen vil maneges heldes wip ### den <schilt> den rvcht er hoher den vezel nider baz ### do frvmt er vil der ringe mit blvote vliezende naz
| ### So we mir dirre leide sprach Aldrianes chint ### nv wichet Hivnen reckn ir lat mich an den wint ### daz der lvft erchvele mich stvrmen mveden man ### do sah man den rechen vil hart herliche gan
###### 1937 | ### Also der strites mvede vz dem hvse spranch ### waz iteniwer swerte vf sinem helm erchlanch ### di niht gesehen heten waz vnders tet sin hant [388b] ### di sprvngen hin engegene dem von Bvergonden lant
###### 1938 | ### Nv wolde got sprach Danchwart moeht ich den boten han ### der minen brvder Hagenen chvnde wizen lan ### daz ich vor disen rechen sten in solher not ### der hvlfe mir von hinnen oder er gelæge bi mir tot
| ### Do sprachen Hivnen recken der bot mvstv sin ### so wir dich tragen toten fver den brvder din ### so siht im erste leide der Gvntheres man ### dv hast dem chvenege Ecel so grozen schaden hi getan
###### 1040 | ### Er sprach nv lat daz drewen vnde wichet hoher baz ### ia getvn ich etelichem noch di ringe naz ### ich wil div mære selbe hince hove sagen ### vnde wil ovh minen herren minen grozen chvmber chlagen
###### 1941 | ### Er leidete sich so sere den Eceln man ### daz si in mit den swerten torsten niht bestan ### so shvzen si der gere so vil in sinen rant ### daz er in dvrch di swære mvse lazen von der hant
| ### Do wanden si in betwingen do er niht schildes trvch ### hey waz er tiefer wnden dvrch di shilde slvch ### des mvse vor im strvchen vil manich chvener man ### dar vmbe lop vil grozen der starche Danchwart gewan
###### 1943 | ### Ze beiden sinen siten sprvngen si im zv ### ia chom ir islicher in den strit ze frv ### do gi er vor den vienden als ein eberswin ### ce walde tvt vor hvnden wi moht er chvener gesin
###### 1944 | ### Sin vart wart erniwet von heizem blvte naz ### iane chvnde ein einech recke gestriten nimmer baz ### sinen vianden danne er het getan ### man sach den Hagenen brvder ce hove herlichen gan
| ### Trvhsæzen vnde shenchen di horten swerte chlanch ### vil maneger do daz trinchen von der hende swanch ### vnde etesliche spise di man ze hove trvch ### do chom im vor der stiegen der starchen viende genvch
###### 1946 | ### Wi nv ir trvhsæzen sprach der mvede degen ### ia soldet ir der geste vil gvetliche pflegen ### vnde soldet ir den her [389a] herren gvte spise tragen ### vnde <liezet> mich den minen herren div mære rehte sagen
###### 1947 | ### Swelher im dvrch sin ellen fver di stiege spranch ### der slvch er eteslichem so grimmen swertes swanch ### daz si dvrch di vorhte vf hoher mvsen stan ### ez het sin <starche> ellen vil michel wnder gatan

<<< Übersicht <<< vorige Seite nächste Seite >>>